package gpsys.cos;

import java.util.Random;
import gpsys.*;
import gpsys.primitives.*;

/**
 * The Chromosome parameters for ADF1 of the terrain robot problem.
 *
 * ADF1 has the following Function and Terminal sets.
 *
 * <pre>
 *              Functions = {IFACS, IFCHARGED, IFSYSUNSAFE}
 *              Terminals = {Left, Right, Forward, Back, Halt}
 * </pre>
 *
 * @version             1.1, 24 Mars 1999
 * @author      <a href="mailto:epierre@e-nef.com">Emmanuel PIERRE</a>
 *                      <address>DEA IARFA,</address>
 */
public class CosSimChromosomeParametersADF1 extends ChromosomeParameters {

	/**
	 * Create the ChromosomeParameters object for ADF1.
	 *
	 * @param robot	The terrainrobot to be controlled.
	 * @param rng	The random number generator to use.
	 */
	public CosSimChromosomeParametersADF1(Robot robot, Random rng) {

		maxDepth		= 9;
		maxDepthAtCreation	= 5;
		maxDepthMutation	= 3;

		// the return type for ADF1
		type = CosSimTypes.Vector2Mod10;

		// the table of all types used by this ADF
		types = new Type[1];
		types[0] = CosSimTypes.Vector2Mod10;

		// the function set
		functions = new Function[3];
                functions[0] = new IFACS(type, robot);
		functions[1] = new IFCHARGED(type, robot);
                functions[2] = new IFSYSUNSAFE(type, robot);

		//functions[1] = new AddVector2Mod10();
		//functions[2] = new ProgN(type, 2);

		// the terminal set
		terminals = new Terminal[5];
		terminals[0] = new Left(robot);
                terminals[1] = new Right(robot);
                terminals[2] = new Forward(robot);
                terminals[3] = new Back(robot);
                terminals[4] = new Halt(robot);
                //terminals[5] = new ConstantVector2Mod10(rng);

		createMethod = CREATE_RAMP_HALF_AND_HALF;
	}
}
